@@ -1,6 +1,7 @@
 package progress
 
 import (
+	"context"
 	"math"
 	"os"
 	"testing"
@@ -143,6 +144,16 @@ func TestProgress_SetStyle(t *testing.T) {
 	assert.Equal(t, StyleCircle.Name, p.Style().Name)
 }
 
+func TestProgress_SetMessageLength(t *testing.T) {
+	p := Progress{}
+	assert.Equal(t, 0, p.lengthMessage)
+
+	p.SetMessageLength(80)
+	assert.Equal(t, 80, p.lengthMessage)
+	p.SetMessageWidth(81)
+	assert.Equal(t, 81, p.lengthMessage)
+}
+
 func TestProgress_SetTrackerLength(t *testing.T) {
 	p := Progress{}
 	assert.Equal(t, 0, p.lengthTracker)
@@ -169,8 +180,8 @@ func TestProgress_SetUpdateFrequency(t *testing.T) {
 	p.initForRender()
 	assert.Equal(t, DefaultUpdateFrequency, p.updateFrequency)
 
-	p.SetUpdateFrequency(time.Duration(time.Second))
-	assert.Equal(t, time.Duration(time.Second), p.updateFrequency)
+	p.SetUpdateFrequency(time.Second)
+	assert.Equal(t, time.Second, p.updateFrequency)
 }
 
 func TestProgress_ShowETA(t *testing.T) {
@@ -222,13 +233,11 @@ func TestProgress_ShowValue(t *testing.T) {
 }
 
 func TestProgress_Stop(t *testing.T) {
-	doneChannel := make(chan bool, 1)
-
 	p := Progress{}
-	p.done = doneChannel
+	p.renderContext, p.renderContextCancel = context.WithCancel(context.Background())
 	p.renderInProgress = true
 	p.Stop()
-	assert.True(t, <-doneChannel)
+	assert.NotNil(t, <-p.renderContext.Done())
 }
 
 func TestProgress_Style(t *testing.T) {
@@ -238,3 +247,11 @@ func TestProgress_Style(t *testing.T) {
 	assert.NotNil(t, p.Style())
 	assert.Equal(t, StyleDefault.Name, p.Style().Name)
 }
+
+func TestProgress_OverallTrackerDisappearsCase(t *testing.T) {
+	p := &Progress{}
+	p.overallTracker = &Tracker{Total: 1, done: true}
+	p.AppendTracker(&Tracker{Total: 1})
+
+	assert.Equal(t, false, p.overallTracker.IsDone())
+}
